# Syntax diagrams

Render syntax diagrams (a.k.a. railroad diagrams) with ease.

## Resources

- [Documentation](https://taminomara.github.io/syntax-diagrams/)
- [Quickstart](https://taminomara.github.io/syntax-diagrams/quickstart.html)
- [Try it in your browser](https://taminomara.github.io/syntax-diagrams/try)

## Requirements

- python >= 3.12

## Installation

```sh
pip install syntax-diagrams
```
